@@ -363,16 +363,21 @@ Tab::findExistingDestination()
   auto nativeDestination = QDir::toNativeSeparators(m_config.m_destination);
   QFileInfo destinationInfo{nativeDestination};
 
-  if (MuxConfig::DoNotSplit == m_config.m_splitMode)
-    return destinationInfo.exists() ? nativeDestination : QString{};
+  if (destinationInfo.exists())
+    return nativeDestination;
+
+  auto splitting = (MuxConfig::DoNotSplit != m_config.m_splitMode)
+                || m_config.m_additionalOptions.contains(QRegularExpression{Q("--split(?:[^a-z-]|$)")});
+  if (!splitting)
+    return {};
 
 #if defined(SYS_WINDOWS)
   auto rePatternOptions     = QRegularExpression::CaseInsensitiveOption;
 #else
   auto rePatternOptions     = QRegularExpression::NoPatternOption;
 #endif
-  auto destinationBaseName  = QRegularExpression::escape(destinationInfo.baseName());
-  auto destinationSuffix    = QRegularExpression::escape(destinationInfo.completeSuffix());
+  auto destinationBaseName  = QRegularExpression::escape(destinationInfo.completeBaseName());
+  auto destinationSuffix    = QRegularExpression::escape(destinationInfo.suffix());
   auto splitNameTestPattern = Q("^%1-\\d+%2%3$").arg(destinationBaseName).arg(destinationSuffix.isEmpty() ? Q("") : Q("\\.")).arg(destinationSuffix);
   auto splitNameTestRE      = QRegularExpression{splitNameTestPattern, rePatternOptions};
   auto destinationDir       = destinationInfo.dir();
@@ -386,7 +391,11 @@ Tab::findExistingDestination()
 
 bool
 Tab::checkIfOverwritingIsOK() {
-  return MainWindow::jobTool()->checkIfOverwritingIsOK(m_config.m_destination, findExistingDestination());
+  auto existingDestination = findExistingDestination();
+  if (existingDestination.isEmpty())
+    return true;
+
+  return MainWindow::jobTool()->checkIfOverwritingIsOK(m_config.m_destination, existingDestination);
 }
 
 bool
