@@ -61,7 +61,7 @@ registerMetaTypes() {
   qRegisterMetaType<mtx::kax_info_c::result_e>("mtx::kax_info_c::result_e");
   qRegisterMetaType<int64_t>("int64_t");
   qRegisterMetaType<EbmlElement *>("EbmlElement *");
-  qRegisterMetaType<boost::optional<int64_t>>("boost::optional<int64_t>");
+  qRegisterMetaType<std::optional<int64_t>>("std::optional<int64_t>");
 }
 
 int
